@@ -28,24 +28,33 @@ def build(args):
     parser = _create_parser()
 
     #No args passed. 
-    if not args: #todo: execute default task.
-        parser.print_help()
-        exit
+    #if not args: #todo: execute default task.
+    #    parser.print_help()
+    #    print("\n\n"+_CREDIT_LINE)
+    #    exit
     # Parse arguments.
     args = parser.parse_args(args)
 
+    if args.version:
+        print('pynt %s' % __version__)
+        sys.exit(0)
+        
     #load build file as a module
     if not path.isfile(args.file):
-        raise Exception("Build file '%s' does not exist" % args.file) 
+        print("Build file '%s' does not exist. Please specify a buld file\n" % args.file) 
+        parser.print_help()
+        sys.exit(1)
+
     module = imp.load_source(path.splitext(path.basename(args.file))[0], args.file)
     
-    # Run task and all it's dependencies.
+    # Run task and all its dependencies.
     if args.list_tasks:
         print_tasks(module, args.file)
     elif not args.tasks:
-        parser.print_help()
-        print("\n")
-        print_tasks(module, args.file)
+        if not _run_default_task(module):
+            parser.print_help()
+            print("\n")
+            print_tasks(module,  args.file)
     else:
         _run_from_task_names(module,args.tasks)
 
@@ -57,32 +66,55 @@ def print_tasks(module, file):
     task_list = "Tasks in build file %s:" % file
     name_width = _get_max_name_length(module)+4
     task_help_format = "\n  {0:<%s} {1: ^10} {2}" % name_width
-    for task in tasks:
-        task_list += task_help_format.format(task.name, "[Ignored]" if task.ignored else '', task.doc)
+    default = _get_default_task(module)
+    for task in sorted(tasks, key=lambda task: task.name):
+        attributes = []
+        if task.ignored:
+            attributes.append('Ignored')
+        if default and task.name == default.name:
+            attributes.append('Default')
+    
+        task_list += task_help_format.format(task.name,
+                                            ('[' + ', '.join(attributes) + ']')
+                                             if attributes else '', 
+                                             task.doc)
     print(task_list + "\n\n"+_CREDIT_LINE)
 
+def _get_default_task(module):
+    matching_tasks = [task for name,task in inspect.getmembers(module,Task.is_task)
+                      if name == "__DEFAULT__"]
+    if matching_tasks:
+        return matching_tasks[0]
+    
+def _run_default_task(module):
+    default_task = _get_default_task(module)
+    if not default_task:
+        return False
+    _run(module, _get_logger(module), default_task, set())
+    return True
+
+
 def _run_from_task_names(module,task_names):
     """
     @type module: module
     @type task_name: string
     @param task_name: Task name, exactly corresponds to function name.
     """
-
     # Create logger.
     logger = _get_logger(module)
-
+    all_tasks = _get_tasks(module)
     completed_tasks = set([])
     for task_name in task_names:
-        task, args, kwargs= _get_task(module,task_name)
+        task, args, kwargs= _get_task(module, task_name, all_tasks)
         _run(module, logger, task, completed_tasks, True, args, kwargs)
 
-def _get_task(module, name):
+def _get_task(module, name, tasks):
     # Get all tasks.
     match = _TASK_PATTERN.match(name)
     if not match:
         raise Exception("Invalid task argument %s" % name)
     task_name, _, args_str = match.groups()
-    tasks = _get_tasks(module)
+    
     args, kwargs= _parse_args(args_str)
     if hasattr(module, task_name):
         return getattr(module, task_name), args, kwargs
@@ -94,7 +126,7 @@ def _get_task(module, name):
                          ', '.join([task.name for task in tasks])))
     if len(matching_tasks) == 1:
         return matching_tasks[0], args, kwargs
-    raise Exception("Conflicting matches %s for task %s " % (
+    raise Exception("Conflicting matches %s for task %s" % (
         ', '.join([task.name for task in matching_tasks]), task_name
     ))
 
@@ -125,13 +157,12 @@ def _run(module, logger, task, completed_tasks, from_command_line = False, args
     @type task: Task
     @type completed_tasts: set Task
     @rtype: set Task
-    @return: Updated set of completed tasks after satisfying all dependancies.
+    @return: Updated set of completed tasks after satisfying all dependencies.
     """
-
-    # Satsify dependancies recursively. Maintain set of completed tasks so each
+    # Satsify dependencies recursively. Maintain set of completed tasks so each
     # task is only performed once.
-    for dependancy in task.dependancies:
-        completed_tasks = _run(module,logger,dependancy,completed_tasks)
+    for dependency in task.dependencies:
+        completed_tasks = _run(module,logger,dependency,completed_tasks)
 
     # Perform current task, if need to.
     if from_command_line or task not in completed_tasks:
@@ -163,10 +194,13 @@ def _create_parser():
     @rtype: argparse.ArgumentParser
     """
     parser = argparse.ArgumentParser()
-    parser.add_argument("tasks", help="perform specified task and all it's dependancies",
+    parser.add_argument("tasks", help="perform specified task and all its dependencies",
                         metavar="task", nargs = '*')
     parser.add_argument('-l', '--list-tasks', help = "List the tasks",
                         action =  'store_true')
+    parser.add_argument('-v', '--version',
+                        help = "Display the version information",
+                        action =  'store_true')
     parser.add_argument('-f', '--file',
                         help = "Build file to read the tasks from. 'build.py' is default value assumed if this argument is unspecified",
                         metavar = "file", default =  "build.py")
@@ -183,7 +217,7 @@ def task(*dependencies, **options):
                     if i == 0:
                         raise Exception("Replace use of @task with @task().")
                     else:
-                        raise Exception("%s is not a task. Each dependancy should be a task." % dependency)
+                        raise Exception("%s is not a task. Each dependency should be a task." % dependency)
                 else:
                     raise Exception("%s is not a task." % dependency)
 
@@ -193,15 +227,15 @@ def task(*dependencies, **options):
 
 class Task(object):
     
-    def __init__(self, func, dependancies, options):
+    def __init__(self, func, dependencies, options):
         """
         @type func: 0-ary function
-        @type dependancies: list of Task objects
+        @type dependencies: list of Task objects
         """
         self.func = func
         self.name = func.__name__
         self.doc = inspect.getdoc(func) or ''
-        self.dependancies = dependancies
+        self.dependencies = dependencies
         self.ignored =  bool(options.get('ignore', False))
         
     def __call__(self,*args,**kwargs):
@@ -222,7 +256,7 @@ def _get_tasks(module):
     """
     # Get all functions that are marked as task and pull out the task object
     # from each (name,value) pair.
-    return [member[1] for member in inspect.getmembers(module,Task.is_task)]
+    return set(member[1] for member in inspect.getmembers(module,Task.is_task))
     
 def _get_max_name_length(module):
     """
